<template>
    <page-container>
        <DeviceInfo />
        <div class="tabs-container">
            <j-spin :spinning="loading">
                <j-tabs v-model:activeKey="activeKey" v-if="!loading">   
                    <j-tab-pane key="1" tab="实时数据"><Running  /> </j-tab-pane>
                    <j-tab-pane key="2" tab="规则策略" force-render><Scene /></j-tab-pane>
                    <j-tab-pane key="3" tab="设备日志"><Log /> </j-tab-pane>
                    <j-tab-pane key="4" tab="物模型"><Metadata :type="'device'" /></j-tab-pane>
                </j-tabs>
            </j-spin>
        </div>
    </page-container>
</template>
<script lang="ts" name="DeviceWarningDetail" setup>
import DeviceInfo from './DeviceInfo.vue';
import { useRouterParams } from '@/utils/hooks/useParams';
import { useInstanceStore } from '@/store/instance';
import { getWebSocket } from '@/utils/websocket';

import Running from './Running/index.vue';
import Metadata from '../Metadata/index.vue';
import Log from './Log/index.vue';

import Scene from './Scene/index.vue';


const activeKey = ref<string>('1');
const loading = ref<boolean>(false);
const statusRef = ref();
const instanceStore = useInstanceStore();
const route = useRoute();
const routerParams = useRouterParams();

const initList = [
    {
        key: 'Info',
        tab: '实例信息',
    },
    {
        key: 'Running',
        tab: '运行状态',
    },
    {
        key: 'Metadata',
        tab: '物模型',
    },
    {
        key: 'Function',
        tab: '设备功能',
    },
    {
        key: 'Log',
        tab: '日志管理',
    },
];


const list = ref([...initList]);

const onTabChange = (e: string) => {
    instanceStore.tabActiveKey = e;
};


onMounted(() => {
    getDetailFn();
});


onBeforeRouteUpdate((to: any) => {
  if (to.params?.id) {
    initPage(to.params?.id)
  }
})

const initPage = async (newId: any) => {
  await instanceStore.refresh(String(newId));
  getStatus(String(newId));
  //list.value = [...initList];
  //getDetail();
  instanceStore.tabActiveKey = 'Info';
}



const getStatus = (id: string) => {
    statusRef.value = getWebSocket(
        `instance-editor-info-status-${id}`,
        `/dashboard/device/status/change/realTime`,
        {
            deviceId: id,
        },
    ).subscribe(() => {
        instanceStore.refresh(id);
    });
};

const getDetailFn = async () => {
    loading.value = true;
    const _id = route.params?.id;
    if (_id) {
        await instanceStore.refresh(String(_id));
        //getStatus(String(_id));
        //list.value = [...initList];
        //getDetail();
    }
    loading.value = false;
    //instanceStore.tabActiveKey = routerParams.params.value.tab || 'Info';
};

</script>
<style scoped lang="less">
.tabs-container {
    margin-top: 16px;
    padding: 16px;
    height: 100%;
    background: white;
}
</style>
